%This is a sample code for reading and plotting TOUGH2 output in MATLAB. 
%Written by Micheal B. Kowalsky, 10/9/2008
%
%It is assumed that the structure of the mesh file is arranged by rows and 
%then columns, and one element ("99999") at the end of the file is ignored.
%This code, meant only to show how one can go about using MATLAB to plot 
%TOUGH2 output, will require user modification for different problems. 
%The developer assumes no responsibility that this code works correctly.

clear all

%Uncomment for Part G:
%ProbDir = 'C:\Temp\TOUGH2_Course_Dec_2008\TOUGH2\morning_day2\2DVZ\Solutions\PartG\';
%eosnum = 9;
%partletter='G'

%Uncomment for Part H:
ProbDir = 'C:\Temp\TOUGH2_Course_Dec_2008\TOUGH2\morning_day2\2DVZ\Solutions\PartH\';
eosnum = 3;
partletter='H'

%printfigs = true;
printfigs = false;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% READ X, Y, AND Z COORDINATES FROM ORIGINAL MESH FILE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

fname       = [ProbDir,'MESH'];
MaxLines    = inf;
NumHeader   = 1;
CharType    = 'Number';
StartCol    = 19;  %Beginning column in MESH file
EndCol      = 20;  %Ending column in MESH file
mat_pre = f_ReadMesh(fname,NumHeader,MaxLines,StartCol,EndCol,CharType);
NumElemIgnore = 1;
mat = mat_pre(1:end-NumElemIgnore);
StartCol    = 51;  
EndCol      = 60;  
x_pre = f_ReadMesh(fname,NumHeader,MaxLines,StartCol,EndCol,CharType);
x = x_pre(1:end-NumElemIgnore);
StartCol    = 61;
EndCol      = 70;
y_pre = f_ReadMesh(fname,NumHeader,MaxLines,StartCol,EndCol,CharType);
y = y_pre(1:end-NumElemIgnore);
StartCol    = 71;
EndCol      = 80;
z_pre = f_ReadMesh(fname,NumHeader,MaxLines,StartCol,EndCol,CharType);
z = z_pre(1:end-NumElemIgnore);
StartCol    = 41;  
EndCol      = 50;  
pmod_pre = f_ReadMesh(fname,NumHeader,MaxLines,StartCol,EndCol,CharType);
pmod = pmod_pre(1:end-1);

NumRows = length(unique(z)); 
NumCols = length(unique(x));
X=reshape(x,NumRows,NumCols);
Z=reshape(z,NumRows,NumCols);
ID = abs(reshape(mat,NumRows,NumCols));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PLOT MATERIAL NUMBER
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

figure(1)
pcolor(X,Z,ID)
xlabel('Distance (m)','fontsize',14)
ylabel('Depth (m)','fontsize',14)
set(gca,'fontsize',14)
set(gca,'box','on')
caxis([1 10])

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PLOT P AND S DISTRIBUTIONS AT DIFFERENT TIMES (DIFFERENT SAVE FILES)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear cmap cmapfull
cmapfull = colormap(1-gray);
cmap = cmapfull(1:4:end,:);

showsat = [0 0.25 0.5 1 2 64];
clear S_prof
for n = 1:length(showsat)

    fname = ['SAVE_',num2str(showsat(n)),'D'];

    NumHeader = 1;
    fnameSAV = [ProbDir,fname];
    pvdat_pre = f_ReadSave(fnameSAV,NumHeader);

    if eosnum == 9
        pvdat = pvdat_pre(1:end-1,1);
        PS = abs(reshape(pvdat(:,end),NumRows,NumCols));
        S = (PS>1)*1+(PS<1).*PS;
        P = (PS>1).*PS+(PS<1).*101.3e3;
    elseif eosnum == 3
        pvdat1 = pvdat_pre(1:end-1,1);
        pvdat2 = pvdat_pre(1:end-1,2);
        Pv = abs(reshape(pvdat1(:,end),NumRows,NumCols));
        Sv = abs(reshape(pvdat2(:,end),NumRows,NumCols));
        S = (Sv<1)*1+(Sv>1).*(1-(Sv-10));
        P = (Pv>1).*Pv+(Pv<1).*101.3e3;
    end
    figure(2+n)
    subplot(1,2,1)
    pcolor(X,Z,S)
    colormap(cmap)
    shading flat
    cb1=colorbar;
    title('Water Saturation','fontsize',14)
    xlabel('Distance (m)','fontsize',13)
    ylabel('Depth (m)','fontsize',13)
    set(gca,'fontsize',12)
    set(gca,'box','on')
    subplot(1,2,2)
    pcolor(X,Z,P*1e-6)
    shading flat
    cb2=colorbar;
    title('Pressure (MPa)','fontsize',14)
    xlabel('Distance (m)','fontsize',13)
    ylabel('Depth (m)','fontsize',13)
    set(gca,'fontsize',12)
    colormap(flipud(jet))
    set(gca,'box','on')
    set(gcf,'paperpositionmode','auto')

    if n == 1
        PosFig1 = get(gcf,'position');
    else
        set(gcf,'position',PosFig1)
    end


    if printfigs == true
        colormap(flipud(jet))
        print([ProbDir,'Part',partletter,'_',num2str(showsat(n)),'D.tiff'],'-dtiff','-r200')
        colormap(1-gray)
        print([ProbDir,'Part',partletter,'_',num2str(showsat(n)),'D_BW.tiff'],'-dtiff','-r200')
    end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PLOT TIME SERIES FOR SEVERAL SAVE FILES
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

figure(2)
clf
title(' ')
showsat = [0 0.25 0.5 1 2 64];

for n = 1:length(showsat)

    subplot(1,6,n)
    NumHeader = 1;
    fname = ['SAVE_',num2str(showsat(n)),'D'];
    fnameSAV = [ProbDir,fname];
    pvdat_pre = f_ReadSave(fnameSAV,NumHeader);

    NumRows = length(unique(z)); 
    NumCols = length(unique(x));

    if eosnum == 9
        pvdat = pvdat_pre(1:end-1,1);
        PS = abs(reshape(pvdat(:,end),NumRows,NumCols));
        S = (PS>1)*1+(PS<1).*PS;
        P = (PS>1).*PS+(PS<1).*101.3e3;
    elseif eosnum == 3
        pvdat1 = pvdat_pre(1:end-1,1);
        pvdat2 = pvdat_pre(1:end-1,2);
        Pv = abs(reshape(pvdat1(:,end),NumRows,NumCols));
        Sv = abs(reshape(pvdat2(:,end),NumRows,NumCols));
        S = (Sv<1)*1+(Sv>1).*(1-(Sv-10));
        P = (Pv>1).*Pv+(Pv<1).*101.3e3;
    end

    plot(S(:,1),Z,'-','marker','o','color','k')
    title([num2str(showsat(n)),' days'],'fontsize',14)
    xlabel('S_a','fontsize',14)
    axis([0.45 1.05 -6 -.126])
    set(gca,'fontsize',12)
    if n == 1
        ylabel('Depth (m)','fontsize',14)
    else
        set(gca,'yticklabel',[ ])
    end    
end
set(gcf,'paperpositionmode','auto')

if printfigs == true
    print([ProbDir,'Part',partletter,'_TimeSeries.tiff'],'-dtiff','-r200')

end






   